@@ -9,17 +9,20 @@ import os
 import re
 import sys
 import warnings
+from pathlib import Path
+from textwrap import indent
 
 import pytest
+from packaging.version import Version
 
 from pytest_doctestplus.utils import ModuleChecker
-from .output_checker import FIX, IGNORE_WARNINGS, OutputChecker, REMOTE_DATA
 
-try:
-    from textwrap import indent
-except ImportError:  # PY2
-    def indent(text, prefix):
-        return '\n'.join([prefix + line for line in text.splitlines()])
+from .output_checker import (FIX, IGNORE_WARNINGS, REMOTE_DATA, SHOW_WARNINGS,
+                             OutputChecker)
+
+_pytest_version = Version(pytest.__version__)
+PYTEST_GT_5 = _pytest_version > Version('5.9.9')
+PYTEST_GE_6_3 = _pytest_version.is_devrelease or _pytest_version >= Version('6.3')
 
 comment_characters = {
     '.txt': '#',
@@ -28,12 +31,12 @@ comment_characters = {
 }
 
 
-# For the IGNORE_WARNINGS option, we create a context manager that doesn't
-# require us to add any imports to the example list and contains everything
-# that is needed to silence warnings.
+# For the IGNORE_WARNINGS and SHOW_WARNINGS option, we create a context manager
+# that doesn't require us to add any imports to the example list and contains
+# everything that is needed to silence or print warnings.
 
 IGNORE_WARNINGS_CONTEXT = """
-class _doctestplus_ignore_all_warnings(object):
+class _doctestplus_ignore_all_warnings:
 
     def __init__(self):
         import warnings
@@ -50,6 +53,26 @@ class _doctestplus_ignore_all_warnings(object):
 """.lstrip()
 
 
+SHOW_WARNINGS_CONTEXT = """
+class _doctestplus_show_all_warnings:
+
+    def __init__(self):
+        import warnings
+        self._cw = warnings.catch_warnings(record=True)
+
+    def __enter__(self, *args, **kwargs):
+        self.result = self._cw.__enter__(*args, **kwargs)
+        import warnings
+        warnings.simplefilter('always')
+        return self.result
+
+    def __exit__(self, *args, **kwargs):
+        self._cw.__exit__(*args, **kwargs)
+        for warn in self.result:
+            print(f'{warn._category_name}: {warn.message}')
+""".lstrip()
+
+
 # these pytest hooks allow us to mark tests and run the marked tests with
 # specific command line options.
 def pytest_addoption(parser):
@@ -169,7 +192,15 @@ def pytest_configure(config):
             if self.fspath.basename == "setup.py":
                 return
             elif self.fspath.basename == "conftest.py":
-                module = self.config.pluginmanager._importconftest(self.fspath)
+                if PYTEST_GE_6_3:
+                    module = self.config.pluginmanager._importconftest(
+                        Path(self.fspath), self.config.getoption("importmode"))
+                elif PYTEST_GT_5:
+                    module = self.config.pluginmanager._importconftest(
+                        self.fspath, self.config.getoption("importmode"))
+                else:
+                    module = self.config.pluginmanager._importconftest(
+                        self.fspath)
             else:
                 try:
                     module = self.fspath.pyimport()
@@ -191,6 +222,7 @@ def pytest_configure(config):
                     if config.getoption('remote_data', 'none') != 'any':
 
                         ignore_warnings_context_needed = False
+                        show_warnings_context_needed = False
 
                         for example in test.examples:
 
@@ -201,13 +233,24 @@ def pytest_configure(config):
                                                   + indent(example.source, '    '))
                                 ignore_warnings_context_needed = True
 
+                            # Same for SHOW_WARNINGS
+                            if example.options.get(SHOW_WARNINGS, False):
+                                example.source = ("with _doctestplus_show_all_warnings():\n"
+                                                  + indent(example.source, '    '))
+                                show_warnings_context_needed = True
+
                             if example.options.get(REMOTE_DATA):
                                 example.options[doctest.SKIP] = True
 
                         # We insert the definition of the context manager to ignore
                         # warnings at the start of the file if needed.
                         if ignore_warnings_context_needed:
-                            test.examples.insert(0, doctest.Example(source=IGNORE_WARNINGS_CONTEXT, want=''))
+                            test.examples.insert(0, doctest.Example(
+                                source=IGNORE_WARNINGS_CONTEXT, want=''))
+
+                        if show_warnings_context_needed:
+                            test.examples.insert(0, doctest.Example(
+                                source=SHOW_WARNINGS_CONTEXT, want=''))
 
                     try:
                         yield doctest_plugin.DoctestItem.from_parent(
@@ -280,6 +323,7 @@ def pytest_configure(config):
             comment_char = comment_characters[ext]
 
             ignore_warnings_context_needed = False
+            show_warnings_context_needed = False
 
             for entry in result:
 
@@ -335,6 +379,12 @@ def pytest_configure(config):
                                         + indent(entry.source, '    '))
                         ignore_warnings_context_needed = True
 
+                    # Same to show warnings
+                    if entry.options.get(SHOW_WARNINGS, False):
+                        entry.source = ("with _doctestplus_show_all_warnings():\n"
+                                        + indent(entry.source, '    '))
+                        show_warnings_context_needed = True
+
                     has_required_modules = DocTestFinderPlus.check_required_modules(required)
                     if skip_all or skip_next or not has_required_modules:
                         entry.options[doctest.SKIP] = True
@@ -347,6 +397,9 @@ def pytest_configure(config):
             if ignore_warnings_context_needed:
                 result.insert(0, doctest.Example(source=IGNORE_WARNINGS_CONTEXT, want=''))
 
+            if show_warnings_context_needed:
+                result.insert(0, doctest.Example(source=SHOW_WARNINGS_CONTEXT, want=''))
+
             return result
 
     config.pluginmanager.register(
@@ -382,7 +435,11 @@ class DoctestPlus(object):
         Skip paths that match any of the doctest_norecursedirs patterns or
         if doctest_only is True then skip all regular test files (eg test_*.py).
         """
-        collect_ignore = config._getconftest_pathlist("collect_ignore", path=path.dirpath())
+        if PYTEST_GE_6_3:
+            dirpath = Path(path).parent
+        else:
+            dirpath = path.dirpath()
+        collect_ignore = config._getconftest_pathlist("collect_ignore", path=dirpath)
 
         # The collect_ignore conftest.py variable should cause all test
         # runners to ignore this file and all subfiles and subdirectories
